@@ -20,7 +20,7 @@
 
 package App::MtAws::ConfigDefinition;
 
-our $VERSION = "1.116";
+our $VERSION = "1.117";
 
 use strict;
 use warnings;
@@ -210,8 +210,6 @@ sub check_https
 			error('LWP::UserAgent 6.x required to use HTTPS') unless LWP->VERSION() ge '6';
 			require LWP::Protocol::https;
 			error('LWP::Protocol::https 6.x required to use HTTPS') unless LWP::Protocol::https->VERSION && LWP::Protocol::https->VERSION ge '6';
-			error('Mozilla::CA is missing. Some distributions decouple it from LWP::Protocol::https (while they don\'t have right to do so). Please install Mozilla::CA')
-				unless is_mozilla_ca_installed();
 		} else {
 			error('IO::Socket::SSL or LWP::Protocol::https is not installed');
 		}
